@@ -18,4 +18,7 @@ DATABASES = {
 
 TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
 
-INSTALLED_APPS = ('report_tracking',)
+INSTALLED_APPS = ('django.contrib.auth',
+                  'django.contrib.contenttypes',
+                  'django_nose',
+                   'report_tracking',)
